# Lunchbot-Python
A Python package for interracting with the @Nero2k Lunchbot API, an API that provides the weekly lunch menu of the Eatery Kista Nod restaurant.

The package fully parses menu attributes into Python objects and is very easy to use.

### Installation

Installation is done via:

`pip install lunchbot-python`

### Quickstart

For a more detailed guide with more code examples, please refer to the the [official documentation](https://lunchbot-python.albins.website).

**Quickstart code is available [here!](https://lunchbot-python.albins.website/quickstart#using-the-library)**

### Changelog

See the "Releases" tab and the documentation.

### More documentation

All functions, variables, and attributes of the code are documented. You can find it on the official library documentation, which is provided by [GitBook](https://gitbook.com) and hosted on https://lunchbot-python.albins.website.

(no code has been uploaded yet, it's just the initial repository that has been created)